@@ -1,30 +1,27 @@
 /****************************************************************************
 ** libmatroska : parse Matroska files, see http://www.matroska.org/
 **
-** <file/class description>
+** <file/class MATROSKA_DLL_API description>
 **
-** Copyright (C) 2002-2003 Steve Lhomme.  All rights reserved.
+** Copyright (C) 2002-2004 Steve Lhomme.  All rights reserved.
 **
 ** This file is part of libmatroska.
 **
-** This file may be distributed under the terms of the Q Public License
-** as defined by Trolltech AS of Norway and appearing in the file
-** LICENSE.QPL included in the packaging of this file.
-**
-** This file may be distributed and/or modified under the terms of the
-** GNU General Public License version 2 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.
-**
-** Licensees holding an other license may use this file in accordance with 
-** the Agreement provided with the Software.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-**
-** See http://www.matroska.org/license/qpl/ for QPL licensing information.
-** See http://www.matroska.org/license/gpl/ for GPL licensing information.
+** This library is free software; you can redistribute it and/or
+** modify it under the terms of the GNU Lesser General Public
+** License as published by the Free Software Foundation; either
+** version 2.1 of the License, or (at your option) any later version.
+** 
+** This library is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+** Lesser General Public License for more details.
+** 
+** You should have received a copy of the GNU Lesser General Public
+** License along with this library; if not, write to the Free Software
+** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **
+** See http://www.matroska.org/license/lgpl/ for LGPL licensing information.**
 ** Contact license@matroska.org if any conditions of this licensing are
 ** not clear to you.
 **
@@ -32,7 +29,7 @@
 
 /*!
 	\file
-	\version \$Id: KaxTag.h,v 1.5 2003/12/28 01:05:31 jcsston Exp $
+	\version \$Id: KaxTag.h,v 1.9 2004/04/14 23:26:17 robux4 Exp $
 	\author Jory Stone     <jcsston @ toughguy.net>
 	\author Steve Lhomme   <robux4 @ users.sf.net>
 */
@@ -52,7 +49,7 @@ using namespace LIBEBML_NAMESPACE;
 
 START_LIBMATROSKA_NAMESPACE
 
-class KaxTag : public EbmlMaster {
+class MATROSKA_DLL_API KaxTag : public EbmlMaster {
 	public:
 		KaxTag();
 		KaxTag(const KaxTag & ElementToClone) :EbmlMaster(ElementToClone) {}
@@ -63,7 +60,7 @@ class KaxTag : public EbmlMaster {
 		EbmlElement * Clone() const {return new KaxTag(*this);}
 };
 
-class KaxTagTargets : public EbmlMaster {
+class MATROSKA_DLL_API KaxTagTargets : public EbmlMaster {
 	public:
 		KaxTagTargets();
 		KaxTagTargets(const KaxTagTargets & ElementToClone) :EbmlMaster(ElementToClone) {}
@@ -74,7 +71,7 @@ class KaxTagTargets : public EbmlMaster {
 		EbmlElement * Clone() const {return new KaxTagTargets(*this);}
 };
 
-class KaxTagGeneral : public EbmlMaster {
+class MATROSKA_DLL_API KaxTagGeneral : public EbmlMaster {
 	public:
 		KaxTagGeneral();
 		KaxTagGeneral(const KaxTagGeneral & ElementToClone) :EbmlMaster(ElementToClone) {}
@@ -85,7 +82,7 @@ class KaxTagGeneral : public EbmlMaster {
 		EbmlElement * Clone() const {return new KaxTagGeneral(*this);}
 };
 
-class KaxTagGenres : public EbmlMaster {
+class MATROSKA_DLL_API KaxTagGenres : public EbmlMaster {
 	public:
 		KaxTagGenres();
 		KaxTagGenres(const KaxTagGenres & ElementToClone) :EbmlMaster(ElementToClone) {}
@@ -96,7 +93,7 @@ class KaxTagGenres : public EbmlMaster {
 		EbmlElement * Clone() const {return new KaxTagGenres(*this);}
 };
 
-class KaxTagAudioSpecific : public EbmlMaster {
+class MATROSKA_DLL_API KaxTagAudioSpecific : public EbmlMaster {
 	public:
 		KaxTagAudioSpecific();
 		KaxTagAudioSpecific(const KaxTagAudioSpecific & ElementToClone) :EbmlMaster(ElementToClone) {}
@@ -107,7 +104,7 @@ class KaxTagAudioSpecific : public EbmlMaster {
 		EbmlElement * Clone() const {return new KaxTagAudioSpecific(*this);}
 };
 
-class KaxTagImageSpecific : public EbmlMaster {
+class MATROSKA_DLL_API KaxTagImageSpecific : public EbmlMaster {
 	public:
 		KaxTagImageSpecific();
 		KaxTagImageSpecific(const KaxTagImageSpecific & ElementToClone) :EbmlMaster(ElementToClone) {}
@@ -118,7 +115,18 @@ class KaxTagImageSpecific : public EbmlMaster {
 		EbmlElement * Clone() const {return new KaxTagImageSpecific(*this);}
 };
 
-class KaxTagTrackUID : public EbmlUInteger {
+class MATROSKA_DLL_API KaxTagTargetType : public EbmlString {
+	public:
+		KaxTagTargetType() {}
+		KaxTagTargetType(const KaxTagTargetType & ElementToClone) :EbmlString(ElementToClone) {}
+		static EbmlElement & Create() {return *(new KaxTagTargetType);}
+		const EbmlCallbacks & Generic() const {return ClassInfos;}
+		static const EbmlCallbacks ClassInfos;
+		operator const EbmlId &() const {return ClassInfos.GlobalId;}
+		EbmlElement * Clone() const {return new KaxTagTargetType(*this);}
+};
+
+class MATROSKA_DLL_API KaxTagTrackUID : public EbmlUInteger {
 	public:
 		KaxTagTrackUID() :EbmlUInteger(0) {}
 		KaxTagTrackUID(const KaxTagTrackUID & ElementToClone) :EbmlUInteger(ElementToClone) {}
@@ -129,7 +137,18 @@ class KaxTagTrackUID : public EbmlUInteger {
 		EbmlElement * Clone() const {return new KaxTagTrackUID(*this);}
 };
 
-class KaxTagChapterUID : public EbmlUInteger {
+class MATROSKA_DLL_API KaxTagEditionUID : public EbmlUInteger {
+	public:
+		KaxTagEditionUID() :EbmlUInteger(0) {}
+		KaxTagEditionUID(const KaxTagEditionUID & ElementToClone) :EbmlUInteger(ElementToClone) {}
+		static EbmlElement & Create() {return *(new KaxTagEditionUID);}
+		const EbmlCallbacks & Generic() const {return ClassInfos;}
+		static const EbmlCallbacks ClassInfos;
+		operator const EbmlId &() const {return ClassInfos.GlobalId;}
+		EbmlElement * Clone() const {return new KaxTagEditionUID(*this);}
+};
+
+class MATROSKA_DLL_API KaxTagChapterUID : public EbmlUInteger {
 	public:
 		KaxTagChapterUID() :EbmlUInteger(0) {}
 		KaxTagChapterUID(const KaxTagChapterUID & ElementToClone) :EbmlUInteger(ElementToClone) {}
@@ -140,7 +159,7 @@ class KaxTagChapterUID : public EbmlUInteger {
 		EbmlElement * Clone() const {return new KaxTagChapterUID(*this);}
 };
 
-class KaxTagAttachmentUID : public EbmlUInteger {
+class MATROSKA_DLL_API KaxTagAttachmentUID : public EbmlUInteger {
 	public:
 		KaxTagAttachmentUID() :EbmlUInteger(0) {}
 		KaxTagAttachmentUID(const KaxTagAttachmentUID & ElementToClone) :EbmlUInteger(ElementToClone) {}
@@ -151,7 +170,7 @@ class KaxTagAttachmentUID : public EbmlUInteger {
 		EbmlElement * Clone() const {return new KaxTagAttachmentUID(*this);}
 };
 
-class KaxTagArchivalLocation : public EbmlUnicodeString {
+class MATROSKA_DLL_API KaxTagArchivalLocation : public EbmlUnicodeString {
 	public:
 		KaxTagArchivalLocation() {}
 		KaxTagArchivalLocation(const KaxTagArchivalLocation & ElementToClone) :EbmlUnicodeString(ElementToClone) {}
@@ -162,7 +181,7 @@ class KaxTagArchivalLocation : public EbmlUnicodeString {
 		EbmlElement * Clone() const {return new KaxTagArchivalLocation(*this);}
 };
 
-class KaxTagAudioEncryption : public EbmlBinary {
+class MATROSKA_DLL_API KaxTagAudioEncryption : public EbmlBinary {
 	public:
 		KaxTagAudioEncryption() {}
 		KaxTagAudioEncryption(const KaxTagAudioEncryption & ElementToClone) :EbmlBinary(ElementToClone){}
@@ -174,7 +193,7 @@ class KaxTagAudioEncryption : public EbmlBinary {
 		EbmlElement * Clone() const {return new KaxTagAudioEncryption(*this);}
 };
 
-class KaxTagAudioGain : public EbmlFloat {
+class MATROSKA_DLL_API KaxTagAudioGain : public EbmlFloat {
 	public:
 		KaxTagAudioGain() {}
 		KaxTagAudioGain(const KaxTagAudioGain & ElementToClone) :EbmlFloat(ElementToClone) {}
@@ -185,7 +204,7 @@ class KaxTagAudioGain : public EbmlFloat {
 		EbmlElement * Clone() const {return new KaxTagAudioGain(*this);}
 };
 
-class KaxTagAudioGenre : public EbmlString {
+class MATROSKA_DLL_API KaxTagAudioGenre : public EbmlString {
 	public:
 		KaxTagAudioGenre() {}
 		KaxTagAudioGenre(const KaxTagAudioGenre & ElementToClone) :EbmlString(ElementToClone) {}
@@ -196,7 +215,7 @@ class KaxTagAudioGenre : public EbmlString {
 		EbmlElement * Clone() const {return new KaxTagAudioGenre(*this);}
 };
 
-class KaxTagAudioPeak : public EbmlFloat {
+class MATROSKA_DLL_API KaxTagAudioPeak : public EbmlFloat {
 	public:
 		KaxTagAudioPeak() {}
 		KaxTagAudioPeak(const KaxTagAudioPeak & ElementToClone) :EbmlFloat(ElementToClone) {}
@@ -207,7 +226,7 @@ class KaxTagAudioPeak : public EbmlFloat {
 		EbmlElement * Clone() const {return new KaxTagAudioPeak(*this);}
 };
 
-class KaxTagBibliography : public EbmlUnicodeString {
+class MATROSKA_DLL_API KaxTagBibliography : public EbmlUnicodeString {
 	public:
 		KaxTagBibliography() {}
 		KaxTagBibliography(const KaxTagBibliography & ElementToClone) :EbmlUnicodeString(ElementToClone) {}
@@ -218,7 +237,7 @@ class KaxTagBibliography : public EbmlUnicodeString {
 		EbmlElement * Clone() const {return new KaxTagBibliography(*this);}
 };
 
-class KaxTagBPM : public EbmlFloat {
+class MATROSKA_DLL_API KaxTagBPM : public EbmlFloat {
 	public:
 		KaxTagBPM() {}
 		KaxTagBPM(const KaxTagBPM & ElementToClone) :EbmlFloat(ElementToClone) {}
@@ -229,7 +248,7 @@ class KaxTagBPM : public EbmlFloat {
 		EbmlElement * Clone() const {return new KaxTagBPM(*this);}
 };
 
-class KaxTagCaptureDPI : public EbmlUInteger {
+class MATROSKA_DLL_API KaxTagCaptureDPI : public EbmlUInteger {
 	public:
 		KaxTagCaptureDPI() {}
 		KaxTagCaptureDPI(const KaxTagCaptureDPI & ElementToClone) :EbmlUInteger(ElementToClone) {}
@@ -240,7 +259,7 @@ class KaxTagCaptureDPI : public EbmlUInteger {
 		EbmlElement * Clone() const {return new KaxTagCaptureDPI(*this);}
 };
 
-class KaxTagCaptureLightness : public EbmlBinary {
+class MATROSKA_DLL_API KaxTagCaptureLightness : public EbmlBinary {
 	public:
 		KaxTagCaptureLightness() {}
 		KaxTagCaptureLightness(const KaxTagCaptureLightness & ElementToClone) :EbmlBinary(ElementToClone){}
@@ -252,7 +271,7 @@ class KaxTagCaptureLightness : public EbmlBinary {
 		EbmlElement * Clone() const {return new KaxTagCaptureLightness(*this);}
 };
 
-class KaxTagCapturePaletteSetting : public EbmlUInteger {
+class MATROSKA_DLL_API KaxTagCapturePaletteSetting : public EbmlUInteger {
 	public:
 		KaxTagCapturePaletteSetting() {}
 		KaxTagCapturePaletteSetting(const KaxTagCapturePaletteSetting & ElementToClone) :EbmlUInteger(ElementToClone) {}
@@ -263,7 +282,7 @@ class KaxTagCapturePaletteSetting : public EbmlUInteger {
 		EbmlElement * Clone() const {return new KaxTagCapturePaletteSetting(*this);}
 };
 
-class KaxTagCaptureSharpness : public EbmlBinary {
+class MATROSKA_DLL_API KaxTagCaptureSharpness : public EbmlBinary {
 	public:
 		KaxTagCaptureSharpness() {}
 		KaxTagCaptureSharpness(const KaxTagCaptureSharpness & ElementToClone) :EbmlBinary(ElementToClone){}
@@ -275,7 +294,7 @@ class KaxTagCaptureSharpness : public EbmlBinary {
 		EbmlElement * Clone() const {return new KaxTagCaptureSharpness(*this);}
 };
 
-class KaxTagCropped : public EbmlUnicodeString {
+class MATROSKA_DLL_API KaxTagCropped : public EbmlUnicodeString {
 	public:
 		KaxTagCropped() {}
 		KaxTagCropped(const KaxTagCropped & ElementToClone) :EbmlUnicodeString(ElementToClone) {}
@@ -286,7 +305,7 @@ class KaxTagCropped : public EbmlUnicodeString {
 		EbmlElement * Clone() const {return new KaxTagCropped(*this);}
 };
 
-class KaxTagDiscTrack : public EbmlUInteger {
+class MATROSKA_DLL_API KaxTagDiscTrack : public EbmlUInteger {
 	public:
 		KaxTagDiscTrack() {}
 		KaxTagDiscTrack(const KaxTagDiscTrack & ElementToClone) :EbmlUInteger(ElementToClone) {}
@@ -297,7 +316,7 @@ class KaxTagDiscTrack : public EbmlUInteger {
 		EbmlElement * Clone() const {return new KaxTagDiscTrack(*this);}
 };
 
-class KaxTagEncoder : public EbmlUnicodeString {
+class MATROSKA_DLL_API KaxTagEncoder : public EbmlUnicodeString {
 	public:
 		KaxTagEncoder() {}
 		KaxTagEncoder(const KaxTagEncoder & ElementToClone) :EbmlUnicodeString(ElementToClone) {}
@@ -308,7 +327,7 @@ class KaxTagEncoder : public EbmlUnicodeString {
 		EbmlElement * Clone() const {return new KaxTagEncoder(*this);}
 };
 
-class KaxTagEncodeSettings : public EbmlUnicodeString {
+class MATROSKA_DLL_API KaxTagEncodeSettings : public EbmlUnicodeString {
 	public:
 		KaxTagEncodeSettings() {}
 		KaxTagEncodeSettings(const KaxTagEncodeSettings & ElementToClone) :EbmlUnicodeString(ElementToClone) {}
@@ -319,7 +338,7 @@ class KaxTagEncodeSettings : public EbmlUnicodeString {
 		EbmlElement * Clone() const {return new KaxTagEncodeSettings(*this);}
 };
 
-class KaxTagEqualisation : public EbmlBinary {
+class MATROSKA_DLL_API KaxTagEqualisation : public EbmlBinary {
 	public:
 		KaxTagEqualisation() {}
 		KaxTagEqualisation(const KaxTagEqualisation & ElementToClone) :EbmlBinary(ElementToClone){}
@@ -331,7 +350,7 @@ class KaxTagEqualisation : public EbmlBinary {
 		EbmlElement * Clone() const {return new KaxTagEqualisation(*this);}
 };
 
-class KaxTagFile : public EbmlUnicodeString {
+class MATROSKA_DLL_API KaxTagFile : public EbmlUnicodeString {
 	public:
 		KaxTagFile() {}
 		KaxTagFile(const KaxTagFile & ElementToClone) :EbmlUnicodeString(ElementToClone) {}
@@ -342,7 +361,7 @@ class KaxTagFile : public EbmlUnicodeString {
 		EbmlElement * Clone() const {return new KaxTagFile(*this);}
 };
 
-class KaxTagInitialKey : public EbmlString {
+class MATROSKA_DLL_API KaxTagInitialKey : public EbmlString {
 	public:
 		KaxTagInitialKey() {}
 		KaxTagInitialKey(const KaxTagInitialKey & ElementToClone) :EbmlString(ElementToClone) {}
@@ -353,7 +372,7 @@ class KaxTagInitialKey : public EbmlString {
 		EbmlElement * Clone() const {return new KaxTagInitialKey(*this);}
 };
 
-class KaxTagKeywords : public EbmlUnicodeString {
+class MATROSKA_DLL_API KaxTagKeywords : public EbmlUnicodeString {
 	public:
 		KaxTagKeywords() {}
 		KaxTagKeywords(const KaxTagKeywords & ElementToClone) :EbmlUnicodeString(ElementToClone) {}
@@ -364,7 +383,7 @@ class KaxTagKeywords : public EbmlUnicodeString {
 		EbmlElement * Clone() const {return new KaxTagKeywords(*this);}
 };
 
-class KaxTagLanguage : public EbmlString {
+class MATROSKA_DLL_API KaxTagLanguage : public EbmlString {
 	public:
 		KaxTagLanguage() {}
 		KaxTagLanguage(const KaxTagLanguage & ElementToClone) :EbmlString(ElementToClone) {}
@@ -375,7 +394,7 @@ class KaxTagLanguage : public EbmlString {
 		EbmlElement * Clone() const {return new KaxTagLanguage(*this);}
 };
 
-class KaxTagLength : public EbmlUInteger {
+class MATROSKA_DLL_API KaxTagLength : public EbmlUInteger {
 	public:
 		KaxTagLength() {}
 		KaxTagLength(const KaxTagLength & ElementToClone) :EbmlUInteger(ElementToClone) {}
@@ -386,7 +405,7 @@ class KaxTagLength : public EbmlUInteger {
 		EbmlElement * Clone() const {return new KaxTagLength(*this);}
 };
 
-class KaxTagMood : public EbmlUnicodeString {
+class MATROSKA_DLL_API KaxTagMood : public EbmlUnicodeString {
 	public:
 		KaxTagMood() {}
 		KaxTagMood(const KaxTagMood & ElementToClone) :EbmlUnicodeString(ElementToClone) {}
@@ -397,7 +416,7 @@ class KaxTagMood : public EbmlUnicodeString {
 		EbmlElement * Clone() const {return new KaxTagMood(*this);}
 };
 
-class KaxTagOfficialAudioFileURL : public EbmlString {
+class MATROSKA_DLL_API KaxTagOfficialAudioFileURL : public EbmlString {
 	public:
 		KaxTagOfficialAudioFileURL() {}
 		KaxTagOfficialAudioFileURL(const KaxTagOfficialAudioFileURL & ElementToClone) :EbmlString(ElementToClone) {}
@@ -408,7 +427,7 @@ class KaxTagOfficialAudioFileURL : public EbmlString {
 		EbmlElement * Clone() const {return new KaxTagOfficialAudioFileURL(*this);}
 };
 
-class KaxTagOfficialAudioSourceURL : public EbmlString {
+class MATROSKA_DLL_API KaxTagOfficialAudioSourceURL : public EbmlString {
 	public:
 		KaxTagOfficialAudioSourceURL() {}
 		KaxTagOfficialAudioSourceURL(const KaxTagOfficialAudioSourceURL & ElementToClone) :EbmlString(ElementToClone) {}
@@ -419,7 +438,7 @@ class KaxTagOfficialAudioSourceURL : public EbmlString {
 		EbmlElement * Clone() const {return new KaxTagOfficialAudioSourceURL(*this);}
 };
 
-class KaxTagOriginalDimensions : public EbmlString {
+class MATROSKA_DLL_API KaxTagOriginalDimensions : public EbmlString {
 	public:
 		KaxTagOriginalDimensions() {}
 		KaxTagOriginalDimensions(const KaxTagOriginalDimensions & ElementToClone) :EbmlString(ElementToClone) {}
@@ -430,7 +449,7 @@ class KaxTagOriginalDimensions : public EbmlString {
 		EbmlElement * Clone() const {return new KaxTagOriginalDimensions(*this);}
 };
 
-class KaxTagOriginalMediaType : public EbmlUnicodeString {
+class MATROSKA_DLL_API KaxTagOriginalMediaType : public EbmlUnicodeString {
 	public:
 		KaxTagOriginalMediaType() {}
 		KaxTagOriginalMediaType(const KaxTagOriginalMediaType & ElementToClone) :EbmlUnicodeString(ElementToClone) {}
@@ -441,7 +460,7 @@ class KaxTagOriginalMediaType : public EbmlUnicodeString {
 		EbmlElement * Clone() const {return new KaxTagOriginalMediaType(*this);}
 };
 
-class KaxTagPlayCounter : public EbmlUInteger {
+class MATROSKA_DLL_API KaxTagPlayCounter : public EbmlUInteger {
 	public:
 		KaxTagPlayCounter() {}
 		KaxTagPlayCounter(const KaxTagPlayCounter & ElementToClone) :EbmlUInteger(ElementToClone) {}
@@ -452,7 +471,7 @@ class KaxTagPlayCounter : public EbmlUInteger {
 		EbmlElement * Clone() const {return new KaxTagPlayCounter(*this);}
 };			 
 
-class KaxTagPlaylistDelay : public EbmlUInteger {
+class MATROSKA_DLL_API KaxTagPlaylistDelay : public EbmlUInteger {
 	public:
 		KaxTagPlaylistDelay() {}
 		KaxTagPlaylistDelay(const KaxTagPlaylistDelay & ElementToClone) :EbmlUInteger(ElementToClone) {}
@@ -463,7 +482,7 @@ class KaxTagPlaylistDelay : public EbmlUInteger {
 		EbmlElement * Clone() const {return new KaxTagPlaylistDelay(*this);}
 };
 
-class KaxTagPopularimeter : public EbmlSInteger {
+class MATROSKA_DLL_API KaxTagPopularimeter : public EbmlSInteger {
 	public:
 		KaxTagPopularimeter() {}
 		KaxTagPopularimeter(const KaxTagPopularimeter & ElementToClone) :EbmlSInteger(ElementToClone) {}
@@ -474,7 +493,7 @@ class KaxTagPopularimeter : public EbmlSInteger {
 		EbmlElement * Clone() const {return new KaxTagPopularimeter(*this);}
 };
 
-class KaxTagProduct : public EbmlUnicodeString {
+class MATROSKA_DLL_API KaxTagProduct : public EbmlUnicodeString {
 	public:
 		KaxTagProduct() {}
 		KaxTagProduct(const KaxTagProduct & ElementToClone) :EbmlUnicodeString(ElementToClone) {}
@@ -485,7 +504,7 @@ class KaxTagProduct : public EbmlUnicodeString {
 		EbmlElement * Clone() const {return new KaxTagProduct(*this);}
 };
 
-class KaxTagRating : public EbmlBinary {
+class MATROSKA_DLL_API KaxTagRating : public EbmlBinary {
 	public:
 		KaxTagRating() {}
 		KaxTagRating(const KaxTagRating & ElementToClone) :EbmlBinary(ElementToClone){}
@@ -497,7 +516,7 @@ class KaxTagRating : public EbmlBinary {
 		EbmlElement * Clone() const {return new KaxTagRating(*this);}
 };
 
-class KaxTagRecordLocation : public EbmlString {
+class MATROSKA_DLL_API KaxTagRecordLocation : public EbmlString {
 	public:
 		KaxTagRecordLocation() {}
 		KaxTagRecordLocation(const KaxTagRecordLocation & ElementToClone) :EbmlString(ElementToClone) {}
@@ -508,7 +527,7 @@ class KaxTagRecordLocation : public EbmlString {
 		EbmlElement * Clone() const {return new KaxTagRecordLocation(*this);}
 };
 
-class KaxTagSetPart : public EbmlUInteger {
+class MATROSKA_DLL_API KaxTagSetPart : public EbmlUInteger {
 	public:
 		KaxTagSetPart() {}
 		KaxTagSetPart(const KaxTagSetPart & ElementToClone) :EbmlUInteger(ElementToClone) {}
@@ -519,7 +538,7 @@ class KaxTagSetPart : public EbmlUInteger {
 		EbmlElement * Clone() const {return new KaxTagSetPart(*this);}
 };
 
-class KaxTagSource : public EbmlUnicodeString {
+class MATROSKA_DLL_API KaxTagSource : public EbmlUnicodeString {
 	public:
 		KaxTagSource() {}
 		KaxTagSource(const KaxTagSource & ElementToClone) :EbmlUnicodeString(ElementToClone) {}
@@ -530,7 +549,7 @@ class KaxTagSource : public EbmlUnicodeString {
 		EbmlElement * Clone() const {return new KaxTagSource(*this);}
 };
 
-class KaxTagSourceForm : public EbmlUnicodeString {
+class MATROSKA_DLL_API KaxTagSourceForm : public EbmlUnicodeString {
 	public:
 		KaxTagSourceForm() {}
 		KaxTagSourceForm(const KaxTagSourceForm & ElementToClone) :EbmlUnicodeString(ElementToClone) {}
@@ -541,7 +560,7 @@ class KaxTagSourceForm : public EbmlUnicodeString {
 		EbmlElement * Clone() const {return new KaxTagSourceForm(*this);}
 };
 
-class KaxTagSubGenre : public EbmlString {
+class MATROSKA_DLL_API KaxTagSubGenre : public EbmlString {
 	public:
 		KaxTagSubGenre() {}
 		KaxTagSubGenre(const KaxTagSubGenre & ElementToClone) :EbmlString(ElementToClone) {}
@@ -552,7 +571,7 @@ class KaxTagSubGenre : public EbmlString {
 		EbmlElement * Clone() const {return new KaxTagSubGenre(*this);}
 };
 
-class KaxTagSubject : public EbmlUnicodeString {
+class MATROSKA_DLL_API KaxTagSubject : public EbmlUnicodeString {
 	public:
 		KaxTagSubject() {}
 		KaxTagSubject(const KaxTagSubject & ElementToClone) :EbmlUnicodeString(ElementToClone) {}
@@ -563,7 +582,7 @@ class KaxTagSubject : public EbmlUnicodeString {
 		EbmlElement * Clone() const {return new KaxTagSubject(*this);}
 };
 
-class KaxTagUnsynchronisedText : public EbmlUnicodeString {
+class MATROSKA_DLL_API KaxTagUnsynchronisedText : public EbmlUnicodeString {
 	public:
 		KaxTagUnsynchronisedText() {}
 		KaxTagUnsynchronisedText(const KaxTagUnsynchronisedText & ElementToClone) :EbmlUnicodeString(ElementToClone) {}
@@ -574,7 +593,7 @@ class KaxTagUnsynchronisedText : public EbmlUnicodeString {
 		EbmlElement * Clone() const {return new KaxTagUnsynchronisedText(*this);}
 };
 
-class KaxTagUserDefinedURL : public EbmlString {
+class MATROSKA_DLL_API KaxTagUserDefinedURL : public EbmlString {
 	public:
 		KaxTagUserDefinedURL() {}
 		KaxTagUserDefinedURL(const KaxTagUserDefinedURL & ElementToClone) :EbmlString(ElementToClone) {}
@@ -585,7 +604,7 @@ class KaxTagUserDefinedURL : public EbmlString {
 		EbmlElement * Clone() const {return new KaxTagUserDefinedURL(*this);}
 };
 
-class KaxTagVideoGenre : public EbmlBinary {
+class MATROSKA_DLL_API KaxTagVideoGenre : public EbmlBinary {
 	public:
 		KaxTagVideoGenre() {}
 		KaxTagVideoGenre(const KaxTagVideoGenre & ElementToClone) :EbmlBinary(ElementToClone){}
@@ -597,7 +616,7 @@ class KaxTagVideoGenre : public EbmlBinary {
 		EbmlElement * Clone() const {return new KaxTagVideoGenre(*this);}
 };
 
-class KaxTagSimple : public EbmlMaster {
+class MATROSKA_DLL_API KaxTagSimple : public EbmlMaster {
 	public:
 		KaxTagSimple();
 		KaxTagSimple(const KaxTagSimple & ElementToClone) :EbmlMaster(ElementToClone) {}
@@ -608,7 +627,7 @@ class KaxTagSimple : public EbmlMaster {
 		EbmlElement * Clone() const {return new KaxTagSimple(*this);}
 };
 
-class KaxTagName : public EbmlUnicodeString {
+class MATROSKA_DLL_API KaxTagName : public EbmlUnicodeString {
 	public:
 		KaxTagName() {}
 		KaxTagName(const KaxTagName & ElementToClone) :EbmlUnicodeString(ElementToClone) {}
@@ -619,7 +638,29 @@ class KaxTagName : public EbmlUnicodeString {
 		EbmlElement * Clone() const {return new KaxTagName(*this);}
 };
 
-class KaxTagString : public EbmlUnicodeString {
+class MATROSKA_DLL_API KaxTagLangue : public EbmlString {
+	public:
+		KaxTagLangue(): EbmlString("und") {}
+		KaxTagLangue(const KaxTagLangue & ElementToClone) :EbmlString(ElementToClone) {}
+		static EbmlElement & Create() {return *(new KaxTagLangue);}
+		const EbmlCallbacks & Generic() const {return ClassInfos;}
+		static const EbmlCallbacks ClassInfos;
+		operator const EbmlId &() const {return ClassInfos.GlobalId;}
+		EbmlElement * Clone() const {return new KaxTagLangue(*this);}
+};
+
+class MATROSKA_DLL_API KaxTagDefault : public EbmlUInteger {
+	public:
+		KaxTagDefault() :EbmlUInteger(1) {}
+		KaxTagDefault(const KaxTagTrackUID & ElementToClone) :EbmlUInteger(ElementToClone) {}
+		static EbmlElement & Create() {return *(new KaxTagDefault);}
+		const EbmlCallbacks & Generic() const {return ClassInfos;}
+		static const EbmlCallbacks ClassInfos;
+		operator const EbmlId &() const {return ClassInfos.GlobalId;}
+		EbmlElement * Clone() const {return new KaxTagDefault(*this);}
+};
+
+class MATROSKA_DLL_API KaxTagString : public EbmlUnicodeString {
 	public:
 		KaxTagString() {}
 		KaxTagString(const KaxTagString & ElementToClone) :EbmlUnicodeString(ElementToClone) {}
@@ -630,7 +671,7 @@ class KaxTagString : public EbmlUnicodeString {
 		EbmlElement * Clone() const {return new KaxTagString(*this);}
 };
 
-class KaxTagBinary : public EbmlBinary {
+class MATROSKA_DLL_API KaxTagBinary : public EbmlBinary {
 	public:
 		KaxTagBinary() {}
 		KaxTagBinary(const KaxTagBinary & ElementToClone) :EbmlBinary(ElementToClone){}
