@@ -29,7 +29,7 @@
 
 /*!
 	\file
-	\version \$Id: KaxChapters.cpp,v 1.7 2004/04/14 23:26:17 robux4 Exp $
+	\version \$Id: KaxChapters.cpp 720 2004-08-19 20:08:44Z mosu $
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 */
 #include "matroska/KaxChapters.h"
@@ -40,12 +40,16 @@ START_LIBMATROSKA_NAMESPACE
 
 EbmlSemantic KaxChapters_ContextList[1] =
 {
-    EbmlSemantic(true, false, KaxEditionEntry::ClassInfos),
+    EbmlSemantic(true, false,  KaxEditionEntry::ClassInfos),
 };
 
-EbmlSemantic KaxEditionEntry_ContextList[1] =
+EbmlSemantic KaxEditionEntry_ContextList[5] =
 {
-    EbmlSemantic(true, false, KaxChapterAtom::ClassInfos),
+    EbmlSemantic(false, true,  KaxEditionUID::ClassInfos),
+    EbmlSemantic(false, true,  KaxEditionFlagHidden::ClassInfos),
+    EbmlSemantic(false, true,  KaxEditionFlagDefault::ClassInfos),
+    EbmlSemantic(false, true,  KaxEditionManaged::ClassInfos),
+    EbmlSemantic(true, false,  KaxChapterAtom::ClassInfos),
 };
 
 EbmlSemantic KaxChapterAtom_ContextList[8] =
@@ -74,6 +78,10 @@ EbmlSemantic KaxChapterDisplay_ContextList[3] =
 
 const EbmlSemanticContext KaxChapters_Context = EbmlSemanticContext(countof(KaxChapters_ContextList), KaxChapters_ContextList, &KaxSegment_Context, *GetKaxGlobal_Context, &KaxChapters::ClassInfos);
 const EbmlSemanticContext KaxEditionEntry_Context = EbmlSemanticContext(countof(KaxEditionEntry_ContextList), KaxEditionEntry_ContextList, &KaxChapters_Context, *GetKaxGlobal_Context, &KaxEditionEntry::ClassInfos);
+const EbmlSemanticContext KaxEditionUID_Context = EbmlSemanticContext(0, NULL, &KaxEditionEntry_Context, *GetKaxGlobal_Context, &KaxEditionUID::ClassInfos);
+const EbmlSemanticContext KaxEditionFlagHidden_Context = EbmlSemanticContext(0, NULL, &KaxEditionEntry_Context, *GetKaxGlobal_Context, &KaxEditionFlagHidden::ClassInfos);
+const EbmlSemanticContext KaxEditionFlagDefault_Context = EbmlSemanticContext(0, NULL, &KaxEditionEntry_Context, *GetKaxGlobal_Context, &KaxEditionFlagDefault::ClassInfos);
+const EbmlSemanticContext KaxEditionManaged_Context = EbmlSemanticContext(0, NULL, &KaxEditionEntry_Context, *GetKaxGlobal_Context, &KaxEditionManaged::ClassInfos);
 const EbmlSemanticContext KaxChapterAtom_Context = EbmlSemanticContext(countof(KaxChapterAtom_ContextList), KaxChapterAtom_ContextList, &KaxEditionEntry_Context, *GetKaxGlobal_Context, &KaxChapterAtom::ClassInfos);
 const EbmlSemanticContext KaxChapterTrack_Context = EbmlSemanticContext(countof(KaxChapterTrack_ContextList), KaxChapterTrack_ContextList, &KaxChapterAtom_Context, *GetKaxGlobal_Context, &KaxChapterTrack::ClassInfos);
 const EbmlSemanticContext KaxChapterDisplay_Context = EbmlSemanticContext(countof(KaxChapterDisplay_ContextList), KaxChapterDisplay_ContextList, &KaxChapterAtom_Context, *GetKaxGlobal_Context, &KaxChapterDisplay::ClassInfos);
@@ -89,6 +97,10 @@ const EbmlSemanticContext KaxChapterCountry_Context = EbmlSemanticContext(0, NUL
 
 EbmlId KaxChapters_TheId          (0x1043A770, 4);
 EbmlId KaxEditionEntry_TheId      (0x45B9, 2);
+EbmlId KaxEditionUID_TheId        (0x45BC, 2);
+EbmlId KaxEditionFlagHidden_TheId (0x45BD, 2);
+EbmlId KaxEditionFlagDefault_TheId(0x45DB, 2);
+EbmlId KaxEditionManaged_TheId    (0x45DD, 2);
 EbmlId KaxChapterAtom_TheId       (0xB6, 1);
 EbmlId KaxChapterUID_TheId        (0x73C4, 2);
 EbmlId KaxChapterTimeStart_TheId  (0x91, 1);
@@ -104,6 +116,10 @@ EbmlId KaxChapterCountry_TheId    (0x437E, 2);
 
 const EbmlCallbacks KaxChapters::ClassInfos(KaxChapters::Create, KaxChapters_TheId, "Chapters", KaxChapters_Context);
 const EbmlCallbacks KaxEditionEntry::ClassInfos(KaxEditionEntry::Create, KaxEditionEntry_TheId, "EditionEntry", KaxEditionEntry_Context);
+const EbmlCallbacks KaxEditionUID::ClassInfos(KaxEditionUID::Create, KaxEditionUID_TheId, "EditionUID", KaxEditionUID_Context);
+const EbmlCallbacks KaxEditionFlagHidden::ClassInfos(KaxEditionFlagHidden::Create, KaxEditionFlagHidden_TheId, "EditionFlagHidden", KaxEditionFlagHidden_Context);
+const EbmlCallbacks KaxEditionFlagDefault::ClassInfos(KaxEditionFlagDefault::Create, KaxEditionFlagDefault_TheId, "EditionFlagDefault", KaxEditionFlagDefault_Context);
+const EbmlCallbacks KaxEditionManaged::ClassInfos(KaxEditionManaged::Create, KaxEditionManaged_TheId, "EditionManaged", KaxEditionManaged_Context);
 const EbmlCallbacks KaxChapterAtom::ClassInfos(KaxChapterAtom::Create, KaxChapterAtom_TheId, "ChapterAtom", KaxChapterAtom_Context);
 const EbmlCallbacks KaxChapterUID::ClassInfos(KaxChapterUID::Create, KaxChapterUID_TheId, "ChapterUID", KaxChapterUID_Context);
 const EbmlCallbacks KaxChapterTimeStart::ClassInfos(KaxChapterTimeStart::Create, KaxChapterTimeStart_TheId, "ChapterTimeStart", KaxChapterTimeStart_Context);
