@@ -27,7 +27,7 @@
 
 /*!
 	\file
-	\version \$Id: KaxCues.cpp,v 1.4 2004/04/14 23:26:17 robux4 Exp $
+	\version \$Id: KaxCues.cpp 647 2004-07-14 13:29:48Z mosu $
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 */
 #include <cassert>
@@ -61,6 +61,13 @@ KaxCues::~KaxCues()
 
 bool KaxCues::AddBlockGroup(const KaxBlockGroup & BlockReference)
 {
+	// Do not add the element if it's already present.
+	std::vector<const KaxBlockGroup *>::iterator ListIdx;
+
+	for (ListIdx = myTempReferences.begin(); ListIdx != myTempReferences.end(); ListIdx++)
+		if (*ListIdx == &BlockReference)
+			return true;
+
 	myTempReferences.push_back(&BlockReference);
 	return true;
 }
