@@ -29,7 +29,7 @@
 
 /*!
 	\file
-	\version \$Id: KaxTag.cpp,v 1.8 2004/04/14 23:26:17 robux4 Exp $
+	\version \$Id: KaxTag.cpp 717 2004-08-19 08:54:57Z robux4 $
 	\author Jory Stone       <jcsston @ toughguy.net>
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 */
@@ -61,12 +61,14 @@ EbmlSemantic KaxTag_ContextList[14] =
 //	EbmlSemantic(false, false, KaxTagUnsynchronisedText::ClassInfos),
 //	EbmlSemantic(false, false, KaxTagUserDefinedURL::ClassInfos),
 	EbmlSemantic(false, false, KaxTagMultiComment::ClassInfos),
-	EbmlSemantic(false, false, KaxTagSimple::ClassInfos),
+	EbmlSemantic(true,  false, KaxTagSimple::ClassInfos),
 };
 
-EbmlSemantic KaxTagTargets_ContextList[3] =
+EbmlSemantic KaxTagTargets_ContextList[5] =
 {	
+	EbmlSemantic(false, true,  KaxTagTargetType::ClassInfos),
 	EbmlSemantic(false, false, KaxTagTrackUID::ClassInfos),
+	EbmlSemantic(false, false, KaxTagEditionUID::ClassInfos),
 	EbmlSemantic(false, false, KaxTagChapterUID::ClassInfos),
 	EbmlSemantic(false, false, KaxTagAttachmentUID::ClassInfos),
 };
@@ -123,11 +125,13 @@ EbmlSemantic KaxTagImageSpecific_ContextList[6] =
 	EbmlSemantic(false, true, KaxTagOriginalDimensions::ClassInfos),
 };
 
-EbmlSemantic KaxTagSimple_ContextList[4] =
+EbmlSemantic KaxTagSimple_ContextList[6] =
 {	
-	EbmlSemantic(false, true, KaxTagName::ClassInfos),
-	EbmlSemantic(false, true, KaxTagString::ClassInfos),
-	EbmlSemantic(false, true, KaxTagBinary::ClassInfos),
+	EbmlSemantic(true,  true,  KaxTagName::ClassInfos),
+	EbmlSemantic(true,  true,  KaxTagLangue::ClassInfos),
+	EbmlSemantic(true,  true,  KaxTagDefault::ClassInfos),
+	EbmlSemantic(false, true,  KaxTagString::ClassInfos),
+	EbmlSemantic(false, true,  KaxTagBinary::ClassInfos),
 	EbmlSemantic(false, false, KaxTagSimple::ClassInfos),
 };
 
@@ -147,7 +151,9 @@ const EbmlSemanticContext KaxTagRating_Context = EbmlSemanticContext(0, NULL, &K
 const EbmlSemanticContext KaxTagSubject_Context = EbmlSemanticContext(0, NULL, &KaxTag_Context, *GetKaxGlobal_Context, &KaxTagSubject::ClassInfos);
 const EbmlSemanticContext KaxTagUnsynchronisedText_Context = EbmlSemanticContext(0, NULL, &KaxTag_Context, *GetKaxGlobal_Context, &KaxTagUnsynchronisedText::ClassInfos);
 const EbmlSemanticContext KaxTagUserDefinedURL_Context = EbmlSemanticContext(0, NULL, &KaxTag_Context, *GetKaxGlobal_Context, &KaxTagUserDefinedURL::ClassInfos);
+const EbmlSemanticContext KaxTagTargetType_Context = EbmlSemanticContext(0, NULL, &KaxTagTargets_Context, *GetKaxGlobal_Context, &KaxTagTargetType::ClassInfos);
 const EbmlSemanticContext KaxTagTrackUID_Context = EbmlSemanticContext(0, NULL, &KaxTagTargets_Context, *GetKaxGlobal_Context, &KaxTagTrackUID::ClassInfos);
+const EbmlSemanticContext KaxTagEditionUID_Context = EbmlSemanticContext(0, NULL, &KaxTagTargets_Context, *GetKaxGlobal_Context, &KaxTagEditionUID::ClassInfos);
 const EbmlSemanticContext KaxTagChapterUID_Context = EbmlSemanticContext(0, NULL, &KaxTagTargets_Context, *GetKaxGlobal_Context, &KaxTagChapterUID::ClassInfos);
 const EbmlSemanticContext KaxTagAttachmentUID_Context = EbmlSemanticContext(0, NULL, &KaxTagTargets_Context, *GetKaxGlobal_Context, &KaxTagAttachmentUID::ClassInfos);
 const EbmlSemanticContext KaxTagArchivalLocation_Context = EbmlSemanticContext(0, NULL, &KaxTagGeneral_Context, *GetKaxGlobal_Context, &KaxTagArchivalLocation::ClassInfos);
@@ -183,6 +189,8 @@ const EbmlSemanticContext KaxTagOriginalDimensions_Context = EbmlSemanticContext
 
 const EbmlSemanticContext KaxTagSimple_Context = EbmlSemanticContext(countof(KaxTagSimple_ContextList), KaxTagSimple_ContextList, &KaxTag_Context, *GetKaxGlobal_Context, &KaxTagSimple::ClassInfos);
 const EbmlSemanticContext KaxTagName_Context = EbmlSemanticContext(0, NULL, &KaxTagSimple_Context, *GetKaxGlobal_Context, &KaxTagName::ClassInfos);
+const EbmlSemanticContext KaxTagLangue_Context = EbmlSemanticContext(0, NULL, &KaxTagSimple_Context, *GetKaxGlobal_Context, &KaxTagLangue::ClassInfos);
+const EbmlSemanticContext KaxTagDefault_Context = EbmlSemanticContext(0, NULL, &KaxTagSimple_Context, *GetKaxGlobal_Context, &KaxTagDefault::ClassInfos);
 const EbmlSemanticContext KaxTagString_Context = EbmlSemanticContext(0, NULL, &KaxTagSimple_Context, *GetKaxGlobal_Context, &KaxTagString::ClassInfos);
 const EbmlSemanticContext KaxTagBinary_Context = EbmlSemanticContext(0, NULL, &KaxTagSimple_Context, *GetKaxGlobal_Context, &KaxTagBinary::ClassInfos);
 
@@ -202,7 +210,9 @@ EbmlId KaxTagRating_TheId                (0x52BC, 2);
 EbmlId KaxTagSubject_TheId               (0x49C1, 2);
 EbmlId KaxTagUnsynchronisedText_TheId    (0x874B, 2);
 EbmlId KaxTagUserDefinedURL_TheId        (0x434A, 2);
+EbmlId KaxTagTargetType_TheId            (0x63CA, 2);
 EbmlId KaxTagTrackUID_TheId              (0x63C5, 2);
+EbmlId KaxTagEditionUID_TheId            (0x63C9, 2);
 EbmlId KaxTagChapterUID_TheId            (0x63C4, 2);
 EbmlId KaxTagAttachmentUID_TheId         (0x63C6, 2);
 EbmlId KaxTagAudioGenre_TheId            (0x65C2, 2);
@@ -238,6 +248,8 @@ EbmlId KaxTagOriginalDimensions_TheId    (0x4933, 2);
 
 EbmlId KaxTagSimple_TheId								 (0x67C8, 2);
 EbmlId KaxTagName_TheId									 (0x45A3, 2);
+EbmlId KaxTagLangue_TheId								 (0x447A, 2);
+EbmlId KaxTagDefault_TheId								 (0x44B4, 2);
 EbmlId KaxTagString_TheId								 (0x4487, 2);
 EbmlId KaxTagBinary_TheId								 (0x4485, 2);
 
@@ -263,7 +275,9 @@ const EbmlCallbacks KaxTagRating::ClassInfos(KaxTagRating::Create, KaxTagRating_
 const EbmlCallbacks KaxTagSubject::ClassInfos(KaxTagSubject::Create, KaxTagSubject_TheId, "Subject", KaxTagSubject_Context);
 const EbmlCallbacks KaxTagUnsynchronisedText::ClassInfos(KaxTagUnsynchronisedText::Create, KaxTagUnsynchronisedText_TheId, "UnsynchronisedText", KaxTagUnsynchronisedText_Context);
 const EbmlCallbacks KaxTagUserDefinedURL::ClassInfos(KaxTagUserDefinedURL::Create, KaxTagUserDefinedURL_TheId, "UserDefinedURL", KaxTagUserDefinedURL_Context);
+const EbmlCallbacks KaxTagTargetType::ClassInfos(KaxTagTargetType::Create, KaxTagTargetType_TheId, "TagTargetType", KaxTagTargetType_Context);
 const EbmlCallbacks KaxTagTrackUID::ClassInfos(KaxTagTrackUID::Create, KaxTagTrackUID_TheId, "TagTrackUID", KaxTagTrackUID_Context);
+const EbmlCallbacks KaxTagEditionUID::ClassInfos(KaxTagEditionUID::Create, KaxTagEditionUID_TheId, "TagEditionUID", KaxTagEditionUID_Context);
 const EbmlCallbacks KaxTagChapterUID::ClassInfos(KaxTagChapterUID::Create, KaxTagChapterUID_TheId, "TagChapterUID", KaxTagChapterUID_Context);
 const EbmlCallbacks KaxTagAttachmentUID::ClassInfos(KaxTagAttachmentUID::Create, KaxTagAttachmentUID_TheId, "TagAttachmentUID", KaxTagAttachmentUID_Context);
 const EbmlCallbacks KaxTagAudioGenre::ClassInfos(KaxTagAudioGenre::Create, KaxTagAudioGenre_TheId, "AudioGenre", KaxTagAudioGenre_Context);
@@ -293,6 +307,8 @@ const EbmlCallbacks KaxTagPopularimeter::ClassInfos(KaxTagPopularimeter::Create,
 
 const EbmlCallbacks KaxTagSimple::ClassInfos(KaxTagSimple::Create, KaxTagSimple_TheId, "TagSimple", KaxTagSimple_Context);
 const EbmlCallbacks KaxTagName::ClassInfos(KaxTagName::Create, KaxTagName_TheId, "TagName", KaxTagName_Context);
+const EbmlCallbacks KaxTagLangue::ClassInfos(KaxTagLangue::Create, KaxTagLangue_TheId, "TagLanguage", KaxTagLangue_Context);
+const EbmlCallbacks KaxTagDefault::ClassInfos(KaxTagDefault::Create, KaxTagDefault_TheId, "TagDefault", KaxTagDefault_Context);
 const EbmlCallbacks KaxTagString::ClassInfos(KaxTagString::Create, KaxTagString_TheId, "TagString", KaxTagString_Context);
 const EbmlCallbacks KaxTagBinary::ClassInfos(KaxTagBinary::Create, KaxTagBinary_TheId, "TagBinary", KaxTagBinary_Context);
 
